Learn R Programming

TROM (version 1.1)

TROM-package: Transcriptome Overlap Measure

Description

select.associated.genes
Select the associated genes of different biological samples
select.associated.orthologs
Select the associated genes of different biological samples among
the genes with orthologs in the other species
choose.z
Choose the suggested threshold for Z-scores
ws.trom
Within-species transcriptome mapping
ws.trom.orthologs
Within-species transcriptome mapping using only ortholog genes
bs.trom
Between-species transcriptome mapping
heatmap.3
Plot the resulting within- or between-species TROM scores in a heatmap
find.top.GO.terms
Find top enriched GO terms

Arguments

Details

Package:
TROM
Type:
Package
Version:
1.1
Date:
2015-06-26
License:
GPL-2

References

Li JJ, Huang H, Bickel PJ, & Brenner SE (2014). Comparison of D. melanogaster and C. elegans developmental stages, tissues, and cells by modENCODE RNA-seq data. Genome Research, 24(7), 1086-1101.

Examples

Run this code
## using TROM to map developmental stages of D. melanogaster and C. elegans

## The .rda files used in this example can be downloaded and unzipped from
## http://www.stat.ucla.edu/~jingyi.li/packages/TROM/TROM_Rdata.zip.
## Not run: 
# load("dm_gene_expr.rda")
# load("ce_gene_expr.rda")
# load("dm_ce_orthologs.rda")
# dm_ce_trom <- bs.trom(sp1_gene_expr = dm_gene_expr, 
#                       sp2_gene_expr = ce_gene_expr, 
#                       sp1_sp2_orthologs = dm_ce_orthologs, z_thre=1.5, 
#                       provide=FALSE)
# heatmap.3(   dm_ce_trom,
#              max_score = 6,
#              Rowv = NULL,
#              Colv = NULL,
#              dendrogram = c("none"),
#              distfun = dist,
#              hclustfun = hclust,
#              xlab = "worm stages",
#              ylab = "fly stages",
#              main = "D. melanogaster vs. C. elegans Stage Mapping",
#              key = TRUE,
#              keysize = 1,
#              trace = "none",
#              density.info = c("none"),
#              col = terrain.colors(120),
#   )
#   ## End(Not run)

Run the code above in your browser using DataLab