Learn R Programming

TROM (version 1.1)

choose.z: Choose the suggested threshold of Z-scores

Description

This function calculates the suggested z_thre for within-species comparison. The suggested z_thre gives the most sparse but still stable correspondance map of the transcriptomes.

Usage

choose.z(sp_gene_expr)

Arguments

sp_gene_expr
a data frame containing gene expression estimates of the species; rows correspond to genes; columns (from the second to the last) correspond to samples, with the first column as gene IDs. Required.

Value

A numeric vector of length one containing the suggested z_thre.

Details

This function calculates the suggested z_thre for the species corresponding to sp_gene_expr to select associated genes and calculate TROM scores. The users can tune z_thre based on the mapping results calculated from the suggested z_thre.

See Also

ws.trom, ws.trom.orthologs

Examples

Run this code
## Calculating the suggested z_thre for D. melanogaster 

## dm_gene_expr.rda can be downloaded and unzipped from
## http://www.stat.ucla.edu/~jingyi.li/packages/TROM/TROM_Rdata.zip.
## Not run: 
# load("dm_gene_expr.rda")
# z_thre <- choose.z(dm_gene_expr)
# ## End(Not run)

Run the code above in your browser using DataLab